==> aroundme_0_5_0.zip: aroundme_0_5_0/aroundme/language/1/barnraiser_01/arrays/arr_homepage.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------
// Tom Calthrop - 20th April 2004 (tom@barnraiser.org)



// HOMEPAGE -------------------------------------------------
$lang['homepage']['page'][1] = 							"welcome.php";
$lang['homepage']['page'][2] = 							"mag_overview.php";
$lang['homepage']['page'][3] = 							"msg_list.php";
$lang['homepage']['page'][4] = 							"my_membership.php";
$lang['homepage']['page'][5] = 							"g_groups.php";
$lang['homepage']['page'][6] = 							"sch_list.php";
$lang['homepage']['page'][7] = 							"sn_network.php";

$lang['homepage']['page_desc'][1] = 					"Welcome page";
$lang['homepage']['page_desc'][2] = 					"Splash magazine page";
$lang['homepage']['page_desc'][3] = 					"Message inbox";
$lang['homepage']['page_desc'][4] = 					"Membership page";
$lang['homepage']['page_desc'][5] = 					"Groups page";
$lang['homepage']['page_desc'][6] = 					"Events and tasks page";
$lang['homepage']['page_desc'][7] = 					"Social network";

?>

==> aroundme_0_5_1.zip: aroundme_0_5_1/aroundme/language/1/barnraiser_01/arrays/arr_homepage.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
//
// Copyright (C) 2003, 2005 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
// 02111-1307, USA.
// -----------------------------------------------------------------------
// Tom Calthrop - 20th April 2004 (tom@barnraiser.org)



// HOMEPAGE -------------------------------------------------
$lang['homepage']['page'][1] = 							"welcome.php";
$lang['homepage']['page'][2] = 							"mag_overview.php";
$lang['homepage']['page'][3] = 							"msg_list.php";
$lang['homepage']['page'][4] = 							"my_membership.php";
$lang['homepage']['page'][5] = 							"g_groups.php";
$lang['homepage']['page'][6] = 							"sch_list.php";
$lang['homepage']['page'][7] = 							"sn_network.php";
$lang['homepage']['page'][8] = 							"g_groups.php?my_groups=1";

$lang['homepage']['page_desc'][1] = 					"Welcome page";
$lang['homepage']['page_desc'][2] = 					"Splash magazine page";
$lang['homepage']['page_desc'][3] = 					"Message inbox";
$lang['homepage']['page_desc'][4] = 					"Membership page";
$lang['homepage']['page_desc'][5] = 					"Groups page";
$lang['homepage']['page_desc'][6] = 					"Events and tasks page";
$lang['homepage']['page_desc'][7] = 					"Social network";
$lang['homepage']['page_desc'][8] = 					"My groups";

?>
